@@ -44,30 +44,37 @@ def get_jobs(jenkins_answers):
             if credentialsId.strip() != "":
                 config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentialsId}</credentialsId>",
                                 config)
+            job_name = job.get("name")
 
             change_name = [
 
                 {
                     'type': 'confirm',
                     'name': 'change_name',
-                    'message': "Change the bmx job name to team_prefix.<oldname>?"
+                    'message': f"Change the bmx job name {job_name} to team_prefix.<oldname>?"
                 }
             ]
+
             change_name_answers = prompt(change_name, style=style)
+
             if change_name_answers.get("change_name"):
                 job_match = re.findall(r'<displayName>.*</displayName>', config)
+                if len(job_match)>0:
+                    job_name = job_match[0].replace("displayName", "").replace("<>", "").replace("</>", "")
 
-                job_name = job_match[0].replace("displayName", "").replace("<>", "").replace("</>", "")
-
-                new_job_name = f"{team_prefix}.{job_name}"
-                config = re.sub("<displayName>.*</displayName>", f"<displayName>{new_job_name}</displayName>", config)
+                    new_job_name = f"{team_prefix}.{job_name}"
+                    config = re.sub("<displayName>.*</displayName>", f"<displayName>{new_job_name}</displayName>", config)
+                else:
+                    print("unable to change name")
 
             with open(job.get("name"), "w") as outfile:
                 outfile.write(config)
                 job_name = job.get("name")
                 server.reconfig_job(job.get("name"), config_xml=config)
-                os.remove(job.get("name"))
-                if is_prompt_user:
+            os.remove(job.get("name"))
+            print(f"completed configuring {job_name}")
+
+            if is_prompt_user:
                     is_okay_to_proceed = [
                         {
                             'type': 'list',
